(* ::Package:: *)

(* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Model file: Sommerfeld-enhanced annihilation scenario


Model parameters:

    mDM     -   DM mass
    gDM     -   # of internal degrees of freedom of DM
    g       -   coupling
    mphi    -   mediator mass

Version: 12-10-2020
Contact: Tobias Binder (Kavli IPMU)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% *)

(*********************** specification of the model ***************************)

Print["----------------- Model: Sommerfeld-enhanced annihilation scenario ----------------"];

cardinfo:={"-------- card: "<>parameters<>" mDM="<>ToString[N[mDM]]<>
           "  gDM="<>ToString[gDM]<>"  g="<>ToString[N[g],CForm]<>
           "  mphi="<>ToString[N[mphi],CForm]<>"--------"};


(*************************** annihilation cross section ***********************)

sv[s_]                      :=  Pi (g^2/(4Pi))^2/mDM^2 S[vrel[s,mDM]/(2 g^2/(4Pi)),mphi/(mDM g^2/(4Pi))];
svnonrel[vrel_]             :=  Pi (g^2/(4Pi))^2/mDM^2 S[vrel/(2 g^2/(4Pi)),mphi/(mDM g^2/(4Pi))]; (* non-relativistic annihilation *)
S[ev_,ef_]                  :=  Pi/ev Sinh[(12ev)/(Pi ef)]/(Cosh[(12ev)/(Pi ef)]-Cos[2Pi Sqrt[6/(Pi^2 ef)-((6ev)/(Pi^2 ef))^2]]); (* s-wave Sommerfeld factor Hulth\[EAcute]n potential *)
vrel[s_, m_]                :=  Sqrt[s (s - 4 m^2)]/(s - 2 m^2); (*relative velocity *)

(* no resonances or thersholds *)
resonance                   :=   {};
threshold                   :=   {};

(*******************************  momentum transfer rate  ****************************)

scatttype                   =   "gamma(x)";

(* full Mandestam t averaged scattering amplitude for Compton-like scattering with massive mediator. For light mediator mass and late KD useful to expand, however, scales are not well separated in all the parameter region shown in arxiv xxxx.xxxx *)
tavMCompotn[mchi_,alpha_,mphi_,omega_,k_]:=-((256 alpha^2 \[Pi]^2 (4 k^2 mchi^2 (32 k^6 mchi^6 (mphi^2+2 mchi omega)+3 (mchi^2+mphi^2+2 mchi omega)^3 (3 mphi^8+24 mchi^6 (k^2+mphi^2)-6 mchi^2 mphi^4 (k^2+mphi^2)+2 mchi^4 (-4 k^4+3 mphi^4)+8 mchi^5 (2 k^2+3 mphi^2) omega+4 mchi^3 mphi^2 (2 k^2+3 mphi^2) omega)-8 k^4 mchi^4 (6 mchi^6+52 mchi^4 mphi^2+51 mchi^2 mphi^4+5 mphi^6+24 mchi^5 omega+68 mchi^3 mphi^2 omega+22 mchi mphi^4 omega+2 k^2 mchi^2 (17 mchi^2+17 mphi^2+10 mchi omega))-6 k^2 mchi^2 (mchi^2+mphi^2+2 mchi omega)^2 (-2 k^2 mchi^2 (-4 mchi^2+mphi^2+6 mchi omega)-3 (-6 mchi^4 mphi^2-2 mchi^2 mphi^4+mphi^6-4 mchi^5 omega+2 mchi mphi^4 omega)))+6 (mchi^2+mphi^2+2 mchi omega)^3 (3 mchi^2 mphi^2-mphi^4+2 mchi^3 omega) (-8 k^4 mchi^4+2 k^2 mchi^2 (2 mchi^2+mphi^2) (6 mchi^2-3 mphi^2+4 mchi omega)+3 mphi^2 (8 mchi^6+2 mchi^4 mphi^2-2 mchi^2 mphi^4+mphi^6+8 mchi^5 omega+4 mchi^3 mphi^2 omega)) ArcTanh[(2 k^2 mchi^2)/(-2 k^2 mchi^2-3 mchi^2 mphi^2+mphi^4-2 mchi^3 omega)]))/(3 (mphi^2+2 mchi omega)^2 (mchi^2+mphi^2+2 mchi omega)^3 (-3 mchi^2 mphi^2+mphi^4-2 mchi^3 omega)));

(* momentum transfer rate for Compton-like scattering with massive mediator. Works for parameters shown in arxiv xxxx.xxxx *)

gam[x_]:=If[x>90 mDM/mphi,
  10^(-80)H[mDM/x]
  ,
  If[x<mDM/mphi,
   10^(10)H[mDM/x]
   ,
   (gDM*3 mDM^4/x)^(-1)(4Pi/((2Pi)^3 64 Pi))NIntegrate[
   (Exp[Sqrt[mphi^2+k^2]/(mDM/x)]-1)^(-1)(1+(Exp[Sqrt[mphi^2+k^2]/(mDM/x)]-1)^(-1))
   (k/Sqrt[mphi^2+k^2])tavMCompotn[mDM,g^2/(4Pi),mphi,Sqrt[mphi^2+k^2],k]
   ,{k,10^(-2)*Max[(mDM/x),Sqrt[mphi (mDM/x)]],14*Max[(mDM/x),Sqrt[mphi (mDM/x)]]},
   Method->{Automatic,"SymbolicProcessing"->0}]]];
